==> EventsManager-0.1.6.1.tar.gz: EventsManager/method.install.php <==
<?php
if (!isset($gCms)) exit;

// Database operations
$db = cmsms()->GetDb();

$dict = NewDataDictionary($db);
$taboptarray = array('mysql' => 'TYPE=MyISAM');

// table : module_events **********************************
$flds = "
	id I KEY AUTO,
	id_category I, 
	status C(40),
	name C(255) NOT NULL,
	url C(255),
	description X,
	start_datetime " . CMS_ADODB_DT . ",
	end_datetime " . CMS_ADODB_DT . ",
	capacity I,
	allow_registration I1,
	allowed_feu_groups C(200),
	price F,
	capacity_per_feu I,
	create_datetime " . CMS_ADODB_DT . ",
	modify_datetime " .CMS_ADODB_DT;
$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events", $flds, $taboptarray);
$dict->ExecuteSQLArray($sqlarray);

// table : module_events_categories **********************************
$flds = "
	id I KEY AUTO,
	name C(255) NOT NULL,
	description X,
	create_datetime " . CMS_ADODB_DT . ",
	modify_datetime " .CMS_ADODB_DT;
$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events_categories", $flds, $taboptarray);
$dict->ExecuteSQLArray($sqlarray);

# table : module_events_registrations ********************************
$flds = "
	id I KEY AUTO,
	id_event I,
	id_user I,
	nb_persons I,
	create_datetime " . CMS_ADODB_DT . ",
	modify_datetime " .CMS_ADODB_DT;
$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events_registrations", $flds, $taboptarray);
$dict->ExecuteSQLArray($sqlarray);

# Templates ***************************************************
# Summary template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_summarytemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_summary_template',$template);
	$this->SetTemplate('summary_Sample',$template);
	$this->SetPreference('dflt_summary_template','Sample');
}

# Detail template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_detailtemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_detail_template',$template);
	$this->SetTemplate('detail_Sample',$template);
	$this->SetPreference('dflt_detail_template','Sample');
}

# Registration template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_registertemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_registration_template',$template);
	$this->SetTemplate('registration_Sample',$template);
	$this->SetPreference('dflt_registration_template','Sample');
}

// Permissions
$this->CreatePermission('Use EventsManager', 'Use EventsManager');

// Preferences
$this->SetPreference('menuname', '');
$this->SetPreference('dflt_detailpage', '-1');
$this->SetPreference('dflt_registrationpage', '-1');

// CMSMS Events
$this->CreateEvent('EventsManagerEventAdded');
$this->CreateEvent('EventsManagerEventEdited');
$this->CreateEvent('EventsManagerEventDeleted');

$this->CreateEvent('EventsManagerCategoryAdded');
$this->CreateEvent('EventsManagerCategoryEdited');
$this->CreateEvent('EventsManagerCategoryDeleted');

$this->CreateEvent('EventsManagerRegistrationAdded');
$this->CreateEvent('EventsManagerRegistrationEdited');

?>

==> EventsManager-0.2.tar.gz: EventsManager/method.install.php <==
<?php
if (!isset($gCms)) exit;

// Database operations
$db = cmsms()->GetDb();

$dict = NewDataDictionary($db);
$taboptarray = array('mysql' => 'TYPE=MyISAM');

// table : module_events **********************************
$flds = "
	id I KEY AUTO,
	id_category I, 
	status C(40),
	name C(255) NOT NULL,
	url C(255),
	description X,
	start_datetime " . CMS_ADODB_DT . ",
	end_datetime " . CMS_ADODB_DT . ",
	capacity I,
	allow_registration I1,
	allowed_feu_groups C(200),
	price F,
	capacity_per_feu I,
	create_datetime " . CMS_ADODB_DT . ",
	modify_datetime " .CMS_ADODB_DT;
$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events", $flds, $taboptarray);
$dict->ExecuteSQLArray($sqlarray);

// table : module_events_categories **********************************
$flds = "
	id I KEY AUTO,
	name C(255) NOT NULL,
	description X,
	create_datetime " . CMS_ADODB_DT . ",
	modify_datetime " .CMS_ADODB_DT;
$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events_categories", $flds, $taboptarray);
$dict->ExecuteSQLArray($sqlarray);

# table : module_events_registrations ********************************
$flds = "
	id I KEY AUTO,
	id_event I,
	id_user I,
	nb_persons I,
	create_datetime " . CMS_ADODB_DT . ",
	modify_datetime " .CMS_ADODB_DT;
$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events_registrations", $flds, $taboptarray);
$dict->ExecuteSQLArray($sqlarray);

# Templates ***************************************************
# Summary template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_summarytemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_summary_template',$template);
	$this->SetTemplate('summary_Sample',$template);
	$this->SetPreference('dflt_summary_template','Sample');
}

# Detail template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_detailtemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_detail_template',$template);
	$this->SetTemplate('detail_Sample',$template);
	$this->SetPreference('dflt_detail_template','Sample');
}

# Registration template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_registertemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_registration_template',$template);
	$this->SetTemplate('registration_Sample',$template);
	$this->SetPreference('dflt_registration_template','Sample');
}

# Registrations list template
$fn = cms_join_path(dirname(__FILE__),'templates','orig_registrationslisttemplate.tpl');
if( file_exists( $fn ) )
{
	$template = file_get_contents( $fn );
	$this->SetPreference('orig_registrationslist_template',$template);
	$this->SetTemplate('registrationslist_Sample',$template);
	$this->SetPreference('dflt_registrationslist_template','Sample');
}

// Permissions
$this->CreatePermission('Use EventsManager', 'Use EventsManager');

// Preferences
$this->SetPreference('menuname', '');
$this->SetPreference('dflt_detailpage', '-1');
$this->SetPreference('dflt_registrationpage', '-1');

// CMSMS Events
$this->CreateEvent('EventsManagerEventAdded');
$this->CreateEvent('EventsManagerEventEdited');
$this->CreateEvent('EventsManagerEventDeleted');

$this->CreateEvent('EventsManagerCategoryAdded');
$this->CreateEvent('EventsManagerCategoryEdited');
$this->CreateEvent('EventsManagerCategoryDeleted');

$this->CreateEvent('EventsManagerRegistrationAdded');
$this->CreateEvent('EventsManagerRegistrationEdited');

?>
